==> zio-aws-rekognition_2.12-5.17.151.2-sources.jar: zio/aws/rekognition/model/StartPersonTrackingResponse.scala <==
package zio.aws.rekognition.model
import zio.aws.rekognition.model.primitives.JobId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class StartPersonTrackingResponse(jobId: Option[JobId] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.StartPersonTrackingResponse = {
    import StartPersonTrackingResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.StartPersonTrackingResponse
      .builder()
      .optionallyWith(
        jobId.map(value => JobId.unwrap(value): java.lang.String)
      )(_.jobId)
      .build()
  }
  def asReadOnly
      : zio.aws.rekognition.model.StartPersonTrackingResponse.ReadOnly =
    zio.aws.rekognition.model.StartPersonTrackingResponse.wrap(buildAwsValue())
}
object StartPersonTrackingResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.StartPersonTrackingResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.StartPersonTrackingResponse =
      zio.aws.rekognition.model
        .StartPersonTrackingResponse(jobId.map(value => value))
    def jobId: Option[JobId]
    def getJobId: ZIO[Any, AwsError, JobId] =
      AwsError.unwrapOptionField("jobId", jobId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.StartPersonTrackingResponse
  ) extends zio.aws.rekognition.model.StartPersonTrackingResponse.ReadOnly {
    override val jobId: Option[JobId] = scala
      .Option(impl.jobId())
      .map(value => zio.aws.rekognition.model.primitives.JobId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.StartPersonTrackingResponse
  ): zio.aws.rekognition.model.StartPersonTrackingResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-rekognition_2.12-6.20.78.2-sources.jar: zio/aws/rekognition/model/StartPersonTrackingResponse.scala <==
package zio.aws.rekognition.model
import zio.aws.rekognition.model.primitives.JobId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class StartPersonTrackingResponse(
    jobId: Optional[JobId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.StartPersonTrackingResponse = {
    import StartPersonTrackingResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.StartPersonTrackingResponse
      .builder()
      .optionallyWith(
        jobId.map(value => JobId.unwrap(value): java.lang.String)
      )(_.jobId)
      .build()
  }
  def asReadOnly
      : zio.aws.rekognition.model.StartPersonTrackingResponse.ReadOnly =
    zio.aws.rekognition.model.StartPersonTrackingResponse.wrap(buildAwsValue())
}
object StartPersonTrackingResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.StartPersonTrackingResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.StartPersonTrackingResponse =
      zio.aws.rekognition.model
        .StartPersonTrackingResponse(jobId.map(value => value))
    def jobId: Optional[JobId]
    def getJobId: ZIO[Any, AwsError, JobId] =
      AwsError.unwrapOptionField("jobId", jobId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.StartPersonTrackingResponse
  ) extends zio.aws.rekognition.model.StartPersonTrackingResponse.ReadOnly {
    override val jobId: Optional[JobId] = zio.aws.core.internal
      .optionalFromNullable(impl.jobId())
      .map(value => zio.aws.rekognition.model.primitives.JobId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.StartPersonTrackingResponse
  ): zio.aws.rekognition.model.StartPersonTrackingResponse.ReadOnly =
    new Wrapper(impl)
}
